@@ -2,19 +2,7 @@
 
 import sys
 
-__all__ = ['nullcontext',
-           'removesuffix']
-
-
-if sys.version_info < (3, 7):
-    import contextlib
-
-    @contextlib.contextmanager
-    def nullcontext(enter_result=None):
-        yield enter_result
-
-else:
-    from contextlib import nullcontext
+__all__ = ['removesuffix']
 
 
 if sys.version_info < (3, 9):
@@ -24,12 +12,9 @@ if sys.version_info < (3, 9):
         >>> removesuffix('spam.bib', '.bib')
         'spam'
         """
-        if suffix and s.endswith(suffix):
-            return s[:-len(suffix)]
-        else:
-            return s
+        return s[:-len(suffix)] if suffix and s.endswith(suffix) else s
 
-else:
+else:  # pragma: no cover
     def removesuffix(s: str, suffix: str) -> str:
         """See https://www.python.org/dev/peps/pep-0616/
 
