@@ -13,17 +13,17 @@ glottolog-admin check --old-languoids
 """
 try:
     from git import Repo
-except ImportError:
+except ImportError:  # pragma: no cover
     Repo = None
 
 from clldutils import jsonlib
 
 
-def run(args):
+def run(args):  # pragma: no cover
     if Repo:
         assert str(Repo(str(args.repos.repos)).active_branch) == 'master', \
             'Command should be run on master branch'
     res = {'language': [], 'family': [], 'dialect': []}
-    for l in args.repos.languoids():
-        res[l.level.name].append(l.id)
+    for lang in args.repos.languoids():
+        res[lang.level.name].append(lang.id)
     jsonlib.dump(res, args.repos.build_path('languoids.json'))
