@@ -1,14 +1,15 @@
 import os
-from tempfile import gettempdir
+import tempfile
 import zipfile
 from urllib.request import urlretrieve
 
-URL = "http://cdstar.shh.mpg.de//bitstreams/EAEA0-A662-A618-386E-0/ldh_description.bib.zip"
+URL = ('http://cdstar.shh.mpg.de/'
+       '/bitstreams/EAEA0-A662-A618-386E-0/ldh_description.bib.zip')
 
 
 def download(bibfile, log):  # pragma: no cover
     fname = 'description.bib'
-    tmpdir = gettempdir()
+    tmpdir = tempfile.gettempdir()
     zipped = os.path.join(tmpdir, fname + '.zip')
     urlretrieve(URL, zipped)
     zip = zipfile.ZipFile(zipped)
